import { PDFDocumentProxy } from 'pdfjs-dist';
import { Highlight, PdfScaleValue, PdfSelection } from '../types';
interface PdfHighlighterProps {
    containerElem: HTMLDivElement | null;
    highlights: Array<Highlight>;
    onScrollAway?(): void;
    pdfScaleValue?: PdfScaleValue;
    onSelection?(PdfSelection: PdfSelection): void;
    selectionPopover?: any;
    enableAreaSelection?(event: MouseEvent): boolean;
    mouseSelectionStyle?: any;
    pdfDocument: PDFDocumentProxy;
    textSelectionColor?: string;
    style?: any;
}
declare class PdfHighlighter {
    private props;
    private popover;
    private highlightBindings;
    private ghostHighlight;
    private selection;
    private scrolledToHighlightId;
    private isAreaSelectionInProgress;
    private isEditInProgress;
    private updatePopoverPosition;
    private contextMenu;
    private currentScaleValue;
    private eventBusPdfJs;
    private linkServicePdfJs;
    private resizeObserver;
    private pdfViewer;
    private mouseSelectionComponent;
    constructor(props: PdfHighlighterProps);
    private initializeViewer;
    private onElementContextMenu;
    private handleTextSelection;
    private clearTextSelection;
    toggleEditInProgress: (flag?: boolean) => void;
    private handleScroll;
    private destroyContextMenu;
    private renderHighlightLayer;
    private handleScaleValue;
    initialize(): void;
    /**
     * Render highlight layers for all pages
     */
    renderHighlightLayers: () => void;
    /**
     * Scroll to a highlight
     * @param highlight - The highlight to scroll to
     */
    scrollToHighlight: (highlight: Highlight) => void;
    /**
     * Set the scale of the PDF Viewer.
     * accepted values are `auto`, `page-fit`, `page-width`, or a number (1 means 100%).
     */
    setScale: (scaleValue: PdfScaleValue) => void;
}
export { PdfHighlighter };
